summaryrefslogtreecommitdiff
path: root/libpod/runtime.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-12-03 10:59:33 -0500
committerGitHub <noreply@github.com>2020-12-03 10:59:33 -0500
commit70284b18cc7d4dc478c439cdda60ba64cfec060b (patch)
treee8bdc4217c89c7891116da9977d8e4ec4848bd0e /libpod/runtime.go
parentc675d8a3c6335e495f7e0f055443a7acb63de911 (diff)
parentf00cc25a7c655022785389e6778693c6a7763bdc (diff)
downloadpodman-70284b18cc7d4dc478c439cdda60ba64cfec060b.tar.gz
podman-70284b18cc7d4dc478c439cdda60ba64cfec060b.tar.bz2
podman-70284b18cc7d4dc478c439cdda60ba64cfec060b.zip
Merge pull request #8479 from rhatdan/log
Drop default log-level from error to warn
Diffstat (limited to 'libpod/runtime.go')
-rw-r--r--libpod/runtime.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/libpod/runtime.go b/libpod/runtime.go
index cdf66a4d0..72bd34a5e 100644
--- a/libpod/runtime.go
+++ b/libpod/runtime.go
@@ -387,8 +387,8 @@ func makeRuntime(ctx context.Context, runtime *Runtime) (retErr error) {
// Don't fatally error.
// This will allow us to ship configs including optional
// runtimes that might not be installed (crun, kata).
- // Only a warnf so default configs don't spec errors.
- logrus.Warnf("Error initializing configured OCI runtime %s: %v", name, err)
+ // Only a infof so default configs don't spec errors.
+ logrus.Infof("Error initializing configured OCI runtime %s: %v", name, err)
continue
}